==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Strona gotowa do druku");
define("_FRIEND","Wylij ten artyku do znajomych");
define("_ARTICLES","Artykuy");
define("_USCORE","Wynik");
define("_DATE","Data");
define("_JANUARY","Stycze");
define("_FEBRUARY","Luty");
define("_MARCH","Marzec");
define("_APRIL","Kwiecie");
define("_MAY","Maj");
define("_JUNE","Czerwiec");
define("_JULY","Lipiec");
define("_AUGUST","Sierpie");
define("_SEPTEMBER","Wrzesie");
define("_OCTOBER","Padziernik");
define("_NOVEMBER","Listopad");
define("_DECEMBER","Grudzie");
define("_SELECTMONTH2VIEW","Prosz wybra miesic ktry chcesz przejrze:");
define("_SHOWALLSTORIES","Poka WSZYSTKIE artykuy");
define("_STORIESARCHIVE","Archiwum artykuw");
define("_ACTIONS","Akcje");
define("_ARCHIVESINDEX","Wykaz archiwum artykuw");
define("_ALLSTORIESARCH","Wszystkie artykuy");
define("_NEXTPAGE","Nastpna strona");
define("_PREVIOUSPAGE","Poprzednia strona");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Strona gotowa do druku");
define("_FRIEND","Wylij ten artyku do znajomych");
define("_ARTICLES","Artykuy");
define("_USCORE","Wynik");
define("_DATE","Data");

define("_SELECTMONTH2VIEW","Prosz wybra miesic ktry chcesz przejrze:");
define("_SHOWALLSTORIES","Poka WSZYSTKIE artykuy");
define("_STORIESARCHIVE","Archiwum artykuw");
define("_ACTIONS","Akcje");
define("_ARCHIVESINDEX","Wykaz archiwum artykuw");
define("_ALLSTORIESARCH","Wszystkie artykuy");
define("_NEXTPAGE","Nastpna strona");
define("_PREVIOUSPAGE","Poprzednia strona");

?>
